Bandera. Actor protocol
(bandera v0.1.0)
Identifies an actor (e.g. a user) for actor and percentage_of_actors gates. The id must be a binary and stable for a given actor across a flag's lifetime.
Implementations ship for binaries, integers, and maps with an :id key; define
the protocol for your own struct to control how it is identified.
Summary
Types
@type t() :: term()
All the types that implement this protocol.