Bandera.Notifications.PhoenixPubSub (bandera v0.1.0)

Phoenix.PubSub cache-busting notifier. Subscribes to a topic and, on a flag change broadcast by ANOTHER node, busts the local cache entry. Self-published changes are ignored. The PubSub server name is read at runtime from config :bandera, cache_bust_notifications: [client: MyApp.PubSub].

Summary

Functions

Returns a specification to start this module under a supervisor.

Starts the notifier GenServer, which subscribes to the PubSub change topic.

Functions

child_spec(init_arg)

Returns a specification to start this module under a supervisor.

See Supervisor.

start_link(opts \\ [])

@spec start_link(keyword()) :: GenServer.on_start()

Starts the notifier GenServer, which subscribes to the PubSub change topic.